#!/bin/bash

#set -vx

echo "This script downloads and interpolates the u and v files from ERAI for Jan 2011,"
echo "for training with nudging LMDZ"

mkdir -p GUIDAGE
cd GUIDAGE
ln -s ../INITIAL/grilles_gcm.nc .

lmax=123 # 0 to 123 (for NCO) =124 timesteps in 6-hourly ERA files for January (=31*4)

mainrea=3DInputData/ReAnalyses
path_erai=ERAI/NETCDF/GLOBAL_075/4xdaily/AN_PL/2011
file_erai=201101.aphei.GLOBAL_075

lmdzpubLMD=/u/lmdz/WWW/pub
lmdzpubLocal=~/LMDZ/pub # "Local" on other computers than the LMD ones 
www=https://lmdz.lmd.jussieu.fr/pub

# A function to fetch files either locally or on the internet
function myget { # the only argument is the file name, with his path relative to "pub"
  # Path of "pub" folder on local computer
  if [ -f ${lmdzpubLMD}/$1 ] ; then
    \cp -f -p ${lmdzpubLMD}/$1 .
  elif [ -f ${lmdzpubLocal}/$1 ] ; then
    \cp -f -p ${lmdzpubLocal}/$1 .
  else
    wget ${www}/$1
    dir=${lmdzpubLocal}/`dirname $1` ; mkdir -p $dir ; cp -r `basename $1` $dir
  fi
}

# Interpolation avec CDO
# from L. Guez
########################################
echo 'Interpolating u and v with cdo'
########################################

# Define the grids needed
for grille in grille_u grille_v
do
    ncks --overwrite --variable=$grille grilles_gcm.nc $grille.nc
done
########################################
echo 'Loop on variables : here u and v '
########################################
for var in u v 
do
#------------------------------#------------------------------
echo 'Extracting u and v '
echo 'unpacking them, as ERAI vars are in "short" format'
#------------------------------#------------------------------ 
    file=$var.$file_erai.nc
    echo myget $mainrea/$path_erai/$file
    myget $mainrea/$path_erai/$file
    ncpdq --overwrite --dimension=time,0,${lmax} --unpack \
      $var.201101.aphei.GLOBAL_075.nc ${var}_ERAI.nc
#------------------------------#------------------------------
    echo "Remapping ${var}, inverting latitudes and levels"
#------------------------------#------------------------------
    cdo remapbil,grille_${var}.nc ${var}_ERAI.nc ${var}_lat_lev.nc
    cdo invertlev -invertlat ${var}_lat_lev.nc tmp${var}.nc
    rm ${var}_lat_lev.nc ${var}_ERAI.nc
done
#------------------------------#------------------------------
echo 'Renaming variables : the code needs them in CAPITAL letters '
#------------------------------#------------------------------
ncrename -v u,UWND -v level,LEVEL -d level,LEVEL -v lonu,LONU -d lonu,LONU \
         -d latu,LATU -v latu,LATU tmpu.nc u.nc
ncrename -v v,VWND -v level,LEVEL -d level,LEVEL -v lonv,LONV -d lonv,LONV \
         -d latv,LATV -v latv,LATV tmpv.nc v.nc
rm grille_[uvs].nc tmpu.nc tmpv.nc
#------------------------------#------------------------------
echo "------------------------------#------------------------------"
echo "For EXPERT USE of nudging on HPC centers (TGCC, Idris):"
echo "see this page :" 
echo "https://lmdz-forge.lmd.jussieu.fr/mediawiki/LMDZPedia/index.php/Cr%C3%A9ation_des_fichiers_de_guidage_et_adaptation_de_l%27ex%C3%A9cution"
echo "------------------------------#------------------------------"
